@@ -1,10 +1,9 @@
 import json
+import pickle
 import sys
-
 import numpy as np
 import requests
-
-
+from collections import ChainMap
 # source: https://github.com/mpld3/mpld3/issues/434#issuecomment-340255689
 # fix for the NumPy array is not JSON serializable
 class NumpyEncoder(json.JSONEncoder):
@@ -17,33 +16,27 @@ class NumpyEncoder(json.JSONEncoder):
 class Grader:
     """Student side grader class
     ...
-
     Attributes
     ----------
     submission_url : str
         API url to fetch data
-
     assignmentKey : str
         test-case filename
-
     cases : dict
         Contains data to be validated with test case functions
-
-
     Methods
     -------
     add_case(test_key_value)
         Saves assignemnt result on the cases variable
-
     submit("email","token")
         Send email and session token along with
         student assignment result in parts variableW
         and filename of test case in assignmentKey variable
     """
 
-    def __init__(self, assignmentKey: str, submission_url: str) -> None:
+    def __init__(self, assignment_key: str, submission_url: str) -> None:
         self.submission_url = submission_url
-        self.assignmentKey = assignmentKey
+        self.assignment_key = assignment_key
         self.cases: dict = {}
         self.errors: list = []
 
@@ -51,8 +44,8 @@ class Grader:
         errors: list = []
         try:
             assert type(self.submission_url) == str, "Invalid submission URL."
-            assert type(self.assignmentKey) == str, "Invalid assignment key."
-            assert len(self.assignmentKey) > 1, "Invalid assignment key."
+            assert type(self.assignment_key) == str, "Invalid assignment key."
+            assert len(self.assignment_key) > 1, "Invalid assignment key."
             assert "http" in self.submission_url, "Invalid submission URL."
             assert type(self.cases) == dict, "Invalid test data."
 
@@ -78,6 +71,7 @@ class Grader:
         except AssertionError as e:
             sys.stdout.write(str(e))
             return False
+    
 
     def submit(self, email: str, token: str) -> bool:
         errors = self.__validate()
@@ -85,7 +79,7 @@ class Grader:
             return {"Error": [x for x in errors]}
 
         submission = {
-            "assignmentKey": self.assignmentKey,
+            "assignment_key": self.assignment_key,
             "student_email": email,
             "secret": token,
             "parts": [self.cases],
@@ -100,17 +94,14 @@ class Grader:
 
             # get response form api
             response = request.json()
-            sys.stdout.write(response)
+            sys.stdout.write(str(response))
             return True
 
         except Exception as e:
             sys.stdout.write("There was an error on response from server.")
             return False
-
-
-if __name__ == "__main__":
-    grader = Grader(
-        "lr_test_case", "http://localhost:5000/api/grader/grade-assignment/"
-    )
-    grader.add_case({"test_case": {"asd": "asd"}})
-    grader.submit(email="asd", token="asd")
+        
+    def make_pickle(self):
+        pickle_file = dict(ChainMap(*list(self.cases.values())))
+        with open(self.assignment_key +'-source' + '.pkl', 'wb') as f:
+            pickle.dump(pickle_file, f)
